﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Linq.Expressions;
using System.Text;
using System.Threading.Tasks;
using JQGridDemo.Models;
using System.Data.Entity;
using System.Data.Entity.Migrations;

namespace JQGridDemo.Repositories
{
    public class CustomerOrdersRepository
    {
        public List<CustomerModel> GetAllCustomers()
        {
            var context = new NorthwindEntities();
            var customers = context.Set<Customer>();
            var orders = context.Set<Order>();
            var query = from c in customers
                        select new CustomerModel
                        {
                            CustomerID = c.CustomerID,
                            CompanyName = c.CompanyName,
                            ContactName = c.ContactName,
                            ContactTitle = c.ContactTitle,
                            Address = c.Address,
                            City = c.City,
                            Region = c.Region,
                            PostalCode = c.PostalCode,
                            Country = c.Country,
                            Phone = c.Phone,
                            Fax = c.Fax
                        };
            var customerList = query.ToList();
            foreach (var c in customerList)
            {
                if (orders.Any(o => o.CustomerID == c.CustomerID))
                {
                    c.HasOrders = "+";
                }
                else c.HasOrders = "";
            }
            return customerList;
        }

        public List<OrderModel> GetOrders(string customerID)
        {
            var context = new NorthwindEntities();
            var customers = context.Set<Customer>();
            var employees = context.Set<Employee>();
            var orders = context.Set<Order>();
            var query = from o in orders
                        join e in employees on o.Employee equals e into OE
                        from oe in OE.DefaultIfEmpty()
                        where o.CustomerID == customerID
                        select new OrderModel
                        {
                            OrderID = o.OrderID,
                            CustomerID = o.CustomerID,
                            EmployeeID = o.EmployeeID,
                            EmployeeName = oe == null ? null : oe.FirstName + " " + oe.LastName,
                            OrderDate = o.OrderDate,
                            RequiredDate = o.RequiredDate,
                            ShippedDate = o.ShippedDate,
                            ShipVia = o.ShipVia,
                            Freight = o.Freight,
                            ShipName = o.ShipName,
                            ShipAddress = o.ShipAddress,
                            ShipCity = o.ShipCity,
                            ShipRegion = o.ShipRegion,
                            ShipPostalCode = o.ShipPostalCode,
                            ShipCountry = o.ShipCountry,
                        };
            return query.ToList();
        }

    }
}